library(ade4)
library(spdep)
library(adegenet)
library(ecodist)
library(rgl)
library(vegetarian)
library(poppr)
library(ape)

######DATA##########
dir()
data<-read.table("Raflp.txt",h=T)
data2<-read.table("Facteurs.txt",h=T)
names(data)
names(data2)
dim(data)
ind<-data[,1]
pop<-data[,2]
sp<-data[,3]
xy<-data2[,4:5]
aflp<-data[,3:330]

dim(aflp)
###########################
#1#Structure gntiques
###########################

aflp.dist<-dist.binary(aflp,method=2) #method2 = pairwise diff
hist(aflp.dist, main="Distribution des diffrences inter gnotypes AFLP")
aflp.dist<-dist.binary(aflp,method=5) #method5 = dice
#PCO
pco<-dudi.pco(aflp.dist, scannf = F, nf = 20)
s.label(pco$li, lab=pop, clab=0.5, boxes=F, grid=F)
s.label(pco$li, lab=ind, clab=0.5, boxes=F, grid=F)

#WARD2
dice.ward<-hclust(aflp.dist, method="ward.D2")
plot(dice.ward, hang = -1, cex = 0.6, labels= pop, main="Dendrogram of Dice distances among Armeria genotypes")

#dapc sur pop
#6 pops
dapc <- dapc(aflp, pop)
scatter(dapc)

#figures
myco<-funky(6)
compoplot(dapc, lab="",ncol=3, xlab="individuals", col=myco)
#tableau assignment pour reprage individu
write.table(data.frame(ind,pop,dapc$posterior), "DAPC6pop_assign.txt")

#Figure
myco<-transp(funky(6))
s.label(pco$li, clab=0.6, lab=pop, grid=F, boxes=F)
s.class(pco$li[,1:2],pop,cellipse=0, axesell=F,cstar=0, cpoint=4, pch=20,col= myco, clab=0, grid=F, add.plot=T)

###########KparK################
#DAPC
#K=2
k2 <- find.clusters(aflp)
dk2<-dapc(aflp,k2$grp)
scatter(dk2)
compoplot(dk2,col=funky(6))
assignplot(dk2)
myco<-transp(funky(6))
s.label(pco$li, clab=0.6, lab=pop, grid=F, boxes=F)
s.class(pco$li[,1:2],k2$grp,cellipse=0, axesell=F,cstar=0, cpoint=4, pch=20,col= myco[c(6,1)], clab=0, grid=F, add.plot=T)

k3<- find.clusters(aflp)
dk3<-dapc(aflp,k3$grp)
scatter(dk3)
compoplot(dk3, col=funky(6))
assignplot(dk3)
s.label(pco$li, clab=0.6, lab=pop, grid=F, boxes=F)
s.class(pco$li[,1:2],k3$grp,cellipse=0, axesell=F,cstar=0, cpoint=4, pch=20,col= myco[c(6,2,1)], clab=0, grid=F, add.plot=T)

k4<- find.clusters(aflp)
dk4<-dapc(aflp,k4$grp)
scatter(dk4)
compoplot(dk4, col=funky(6))
assignplot(dk4)
s.label(pco$li, clab=0.6, lab=pop, grid=F, boxes=F)
s.class(pco$li[,1:2],k4$grp,cellipse=0, axesell=F,cstar=0, cpoint=4, pch=20,col= myco[c(6,5,2,1)], clab=0, grid=F, add.plot=T)

k5<- find.clusters(aflp)
dk5<-dapc(aflp,k5$grp)
scatter(dk5)
compoplot(dk5, col=funky(6))
assignplot(dk5)
s.label(pco$li, clab=0.6, lab=pop, grid=F, boxes=F)
s.class(pco$li[,1:2],k5$grp,cellipse=0, axesell=F,cstar=0, cpoint=4, pch=20,col= myco, clab=0, grid=F, add.plot=T)

k6<- find.clusters(aflp)
dk6<-dapc(aflp,k6$grp)
scatter(dk6, mstree=T)
compoplot(dk6, col=funky(6))
assignplot(dk6)
s.label(pco$li, clab=0.6, lab=pop, grid=F, boxes=F)
s.class(pco$li[,1:2],k6$grp,cellipse=0, axesell=F,cstar=0, cpoint=4, pch=20,col= myco, clab=0, grid=F, add.plot=T)


#Figures finales STRUCTURE & DAPC
#article
scatter(dk6)
myco<-seasun(24)
showCols(myco)
compoplot(dk6, col=myco[c(12,17,1,10,7,24)], lab="", legend=F)

dir()
struct<-read.table("Structure K2 K4.txt", h=T)
compoplot(as.matrix(struct[,2:3]), col=myco[c(12,24)], lab="", legend=F)
compoplot(as.matrix(struct[,4:7]), col=myco[c(24,8,12,1)], lab="", legend=F)


#compoplot rapport
myco<-seasun(24)
compoplot(dk2, col=myco[c(1,24)], lab="", legend=F)
compoplot(dk3, col=myco[c(1,24,8)], lab="", legend=F)
compoplot(dk4, col=myco[c(8,12,24,1)], lab="", legend=F)
compoplot(dk5, col=myco[c(1,24,12,8,17)], lab="", legend=F)
compoplot(dk6, col=myco[c(1,8,17,12,24,10)], lab="", legend=F)
#PCO illustre
s.label(pco$li, clab=0.6, lab=pop, grid=F, boxes=F, xlim=c(-0.25,0.30), ylim=c(-0.30,0.20))
s.class(pco$li[,1:2],k6$grp,cellipse=0, axesell=F,cstar=0, cpoint=5, pch=20,col= transp(myco[c(8,24,1,12,17,10)]), clab=0, grid=F, add.plot=T)


#NJ & PCO distance inter pop
obj <- df2genind(aflp, ncode=1, type="PA")
aflpop<-genind2genpop(obj, pop=pop)
nei<-nei.dist(aflpop)
plot(nj(nei), "u", cex=2)

#assignment values
as.data.frame(ind)->ind
write.table(cbind(ind,dk6$posterior),"PostDk6.txt")



